import request from '@/apps/mobile/utils/request'

// 用户管理 分页查询
export function queryPageUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/listUser',
        data,
    });
}

//  新增
export function addDataUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/addUser',
        data,
    });
}

// 删除
export function removeDataUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/deleteUser',
        data,
    });
}

// 编辑
export function editDataUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/updateUser',
        data,
    });
}

// 获取公司列表
export function queryPageCompany(data) {
    return request({
        method: 'post',
        url: '/api/maintenanceCompanys/query-page',
        data,
    });
}

// 查询用户可以升级为那种VIP
export function toWhichVip(id) {
    return request({
        method: 'post',
        url: `/api/userInfos/toWhichVip/${id}`,
    });
}

//升级为会员
export function toVip(data) {
    return request({
        method: 'post',
        url: `/api/userInfos/toVip`,
        data
    });
}

// 取消会员
export function cancelVip(data) {
    return request({
        method: 'post',
        url: `/api/userInfos/cancelVip`,
        data
    });
}

// 查询app用户类型
export function queryCustomerType(data) {
    return request({
        method: 'post',
        url: '/api/userLevelRules/query-page',
        data,
    });
}


// 冻结用户
export function freezeUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/deleteUser',
        data,
    });
}

// 解冻用户
export function unfreezeUser(data) {
    return request({
        method: 'post',
        url: '/api/userInfos/noDeleteUser',
        data,
    });
}



// 后台查询个人返利信息
export function queryUserRebates(id) {
    return request({
        method: 'post',
        url: `/api/userRebates/getAllRebateOfWeb/${id}`,
    });
}


// 获取用户详情
export function queryUserInfo(id) {
    return request({
        method: 'get',
        url: `/api/userInfos/query/${id}`,
    });
}


// 邀请成为专家
export function inviteToBeAnExpert(id) {
    return request({
        method: 'get',
        url: `/api/userInfos/invitationUserToExpert?userId=${id}`,
    });
}




